@@ -5,8 +5,8 @@ from typing import Optional
 
 @strawberry.type
 class OAuthPublicConfiguration:
-    clientId: Optional[str] = None
-    authorizationUrl: Optional[str] = None
+    clientID: Optional[str] = None
+    authorizationURL: Optional[str] = None
     scopes: Optional[str] = None
     redirectUrl: Optional[str] = None
 
