@@ -87,8 +87,8 @@ class SSOManager:
     def public_graphql(self) -> PublicSSOConfiguration:
         return PublicSSOConfiguration(
             oAuth=OAuthPublicConfiguration(
-                clientId=self.oAuth.clientID,
-                authorizationUrl=self.oAuth.provider.authorizationEndpoint,
+                clientID=self.oAuth.clientID,
+                authorizationURL=self.oAuth.provider.authorizationEndpoint,
                 scopes=self.oAuth.scopes,
                 redirectUrl=self.oAuth.redirectURI,
             ) if self.oAuthEnabled and self.oAuth else None,
